@@ -953,36 +953,22 @@ gsd_ldsm_get_config (void)
         gchar **settings_list;
 
         free_percent_notify = g_settings_get_double (settings, SETTINGS_FREE_PC_NOTIFY_KEY);
-        if (free_percent_notify >= 1 || free_percent_notify < 0) {
-                g_warning ("Invalid configuration of free_percent_notify: %f\n" \
-                           "Using sensible default", free_percent_notify);
-                free_percent_notify = 0.05;
-        }
-
         free_percent_notify_again = g_settings_get_double (settings, SETTINGS_FREE_PC_NOTIFY_AGAIN_KEY);
-        if (free_percent_notify_again >= 1 || free_percent_notify_again < 0) {
-                g_warning ("Invalid configuration of free_percent_notify_again: %f\n" \
-                           "Using sensible default\n", free_percent_notify_again);
-                free_percent_notify_again = 0.01;
-        }
 
         free_size_gb_no_notify = g_settings_get_int (settings, SETTINGS_FREE_SIZE_NO_NOTIFY);
         min_notify_period = g_settings_get_int (settings, SETTINGS_MIN_NOTIFY_PERIOD);
 
         if (ignore_paths != NULL) {
                 g_slist_foreach (ignore_paths, (GFunc) g_free, NULL);
-                g_slist_free (ignore_paths);
-                ignore_paths = NULL;
+                g_clear_pointer (&ignore_paths, g_slist_free);
         }
 
         settings_list = g_settings_get_strv (settings, SETTINGS_IGNORE_PATHS);
         if (settings_list != NULL) {
-                gint i;
+                guint i;
 
-                for (i = 0; i < G_N_ELEMENTS (settings_list); i++) {
-                        if (settings_list[i] != NULL)
-                                ignore_paths = g_slist_append (ignore_paths, g_strdup (settings_list[i]));
-                }
+                for (i = 0; settings_list[i] != NULL; i++)
+                        ignore_paths = g_slist_prepend (ignore_paths, g_strdup (settings_list[i]));
 
                 /* Make sure we dont leave stale entries in ldsm_notified_hash */
                 g_hash_table_foreach_remove (ldsm_notified_hash,
