@@ -553,7 +553,6 @@ ungrab_accelerator_complete (GObject      *object,
                              GAsyncResult *result,
                              gpointer      user_data)
 {
-	GsdMediaKeysManager *manager = user_data;
 	shell_key_grabber_call_ungrab_accelerator_finish (SHELL_KEY_GRABBER (object),
 	                                                  NULL, result, NULL);
 }
@@ -1655,6 +1654,22 @@ do_video_rotate_action (GsdMediaKeysManager *manager,
         return FALSE;
 }
 
+static void
+do_video_rotate_lock_action (GsdMediaKeysManager *manager,
+                             gint64               timestamp)
+{
+        GSettings *settings;
+        gboolean locked;
+
+        settings = g_settings_new ("org.gnome.settings-daemon.peripherals.touchscreen");
+        locked = !g_settings_get_boolean (settings, "orientation-lock");
+        g_settings_set_boolean (settings, "orientation-lock", locked);
+        g_object_unref (settings);
+
+        show_osd (manager, locked ? "rotation-locked-symbolic"
+                                  : "rotation-allowed-symbolic", NULL, -1);
+}
+
 static void
 do_toggle_accessibility_key (const char *key)
 {
@@ -1809,6 +1824,7 @@ do_config_power_action (GsdMediaKeysManager *manager,
                 power_action_hibernate (manager);
                 break;
         case GSD_POWER_ACTION_BLANK:
+        case GSD_POWER_ACTION_LOGOUT:
         case GSD_POWER_ACTION_NOTHING:
                 /* these actions cannot be handled by media-keys and
                  * are not used in this context */
@@ -2052,6 +2068,9 @@ do_action (GsdMediaKeysManager *manager,
         case ROTATE_VIDEO_KEY:
                 do_video_rotate_action (manager, timestamp);
                 break;
+        case ROTATE_VIDEO_LOCK_KEY:
+                do_video_rotate_lock_action (manager, timestamp);
+                break;
         case MAGNIFIER_KEY:
                 do_magnifier_action (manager);
                 break;
@@ -2306,12 +2325,11 @@ start_media_keys_idle_cb (GsdMediaKeysManager *manager)
         ensure_cancellable (&manager->priv->grab_cancellable);
         ensure_cancellable (&manager->priv->shell_cancellable);
 
-        manager->priv->name_owner_id =
-                g_bus_watch_name (G_BUS_TYPE_SESSION,
-                                  SHELL_DBUS_NAME, 0,
-                                  on_shell_appeared,
-                                  on_shell_vanished,
-                                  manager, NULL);
+        manager->priv->name_owner_id = g_bus_watch_name (G_BUS_TYPE_SESSION,
+                                                         SHELL_DBUS_NAME, 0,
+                                                         on_shell_appeared,
+                                                         on_shell_vanished,
+                                                         manager, NULL);
 
         gnome_settings_profile_end (NULL);
 
